can_lm: Transform a Multivariate Linear model mlm to a Canonical Representation
Description
This function uses candisc to transform the responses in a
multivariate linear model to scores on canonical variables for a given term and then uses
those scores as responses in a linear (lm) or multivariate linear model (mlm).
Usage
can_lm(mod, term, ...)
Value
A lm object if term is a rank 1 hypothesis, otherwise a mlm object
Arguments
mod
A mlm object
term
One term in that model
...
Arguments passed to candisc
Author
Michael Friendly
Details
The function constructs a model formula of the form Can ~ terms
where Can is the canonical score(s) and terms are the terms in the original mlm,
then runs lm() with that formula.